==> org.eclipse.riena.beans.common.source_2.0.0.v20100615_2_0_0.jar: org/eclipse/riena/beans/common/PropertyFailure.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2009 compeople AG and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    compeople AG - initial API and implementation
 *******************************************************************************/
package org.eclipse.riena.beans.common;

import org.eclipse.riena.core.exception.Failure;

/**
 * A runtime exception that is the abstract superclass for all exceptions around
 * Java Bean properties in the JGoodies Data Binding framework.
 */
abstract public class PropertyFailure extends Failure {

	private static final long serialVersionUID = -7432493570829272979L;

	/**
	 * Constructs a new exception instance with the specified detail message.
	 * The cause is not initialized.
	 * 
	 * @param message
	 *            the detail message. The detail message is saved for later
	 *            retrieval by the {@link #getMessage()}method.
	 */
	public PropertyFailure(String message) {
		this(message, null);
	}

	/**
	 * Constructs a new exception instance with the specified detail message and
	 * cause.
	 * 
	 * @param message
	 *            the detail message (which is saved for later retrieval by the
	 *            {@link #getMessage()}method).
	 * @param cause
	 *            the cause (which is saved for later retrieval by the
	 *            {@link #getCause()}method). (A<code>null</code> value is
	 *            permitted, and indicates that the cause is nonexistent or
	 *            unknown.)
	 */
	public PropertyFailure(String message, Throwable cause) {
		super(message, cause);
	}
}

==> org.eclipse.riena.beans.common.source_3.0.0.v20110614_3_0_0_0.jar: org/eclipse/riena/beans/common/PropertyFailure.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2011 compeople AG and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    compeople AG - initial API and implementation
 *******************************************************************************/
package org.eclipse.riena.beans.common;

import org.eclipse.riena.core.exception.Failure;

/**
 * A runtime exception that is the abstract superclass for all exceptions around
 * Java Bean properties in the JGoodies Data Binding framework.
 */
abstract public class PropertyFailure extends Failure {

	private static final long serialVersionUID = -7432493570829272979L;

	/**
	 * Constructs a new exception instance with the specified detail message.
	 * The cause is not initialized.
	 * 
	 * @param message
	 *            the detail message. The detail message is saved for later
	 *            retrieval by the {@link #getMessage()}method.
	 */
	public PropertyFailure(final String message) {
		this(message, null);
	}

	/**
	 * Constructs a new exception instance with the specified detail message and
	 * cause.
	 * 
	 * @param message
	 *            the detail message (which is saved for later retrieval by the
	 *            {@link #getMessage()}method).
	 * @param cause
	 *            the cause (which is saved for later retrieval by the
	 *            {@link #getCause()}method). (A<code>null</code> value is
	 *            permitted, and indicates that the cause is nonexistent or
	 *            unknown.)
	 */
	public PropertyFailure(final String message, final Throwable cause) {
		super(message, cause);
	}
}
